@@ -232,46 +232,45 @@ impl Expansion for StridedSlice {
             .iter()
             .map(|i| Ok(target.outlet_fact(*i)?.konst.clone()))
             .collect::<TractResult<_>>()?;
-        if params.iter().all(|p| p.is_some()) {
-            let params: TVec<&Tensor> = params.iter().map(|o| &**o.as_ref().unwrap()).collect();
-            let input_shape = target.outlet_fact(inputs[0])?.shape.clone();
-            let strides: TVec<i32> = if let Some(i) = self.optional_steps_input {
-                let strides = params[i - 1].cast_to::<i32>()?;
-                strides.as_slice::<i32>()?.into()
-            } else {
-                tvec![1; input_shape.rank()]
-            };
-            let axes: TVec<usize> = if let Some(i) = self.optional_axes_input {
-                let axes = params[i - 1].cast_to::<i32>()?;
-                axes.as_slice::<i32>()?
-                    .iter()
-                    .map(|&i| if i < 0 { input_shape.rank() as i32 + i } else { i } as usize)
-                    .collect()
-            } else {
-                (0..input_shape.rank()).collect()
-            };
-            let mut wire = inputs[0];
-            let input = target.outlet_fact(wire)?.clone();
-            for (ix, &axis) in axes.iter().enumerate() {
+        let input_shape = target.outlet_fact(inputs[0])?.shape.clone();
+        let strides: TVec<i32> = if let Some(i) = self.optional_steps_input {
+            let strides = params[i - 1]
+                .as_ref()
+                .context("StridedSlice is typable only if stride is a const")?
+                .cast_to::<i32>()?;
+            strides.as_slice::<i32>()?.into()
+        } else {
+            tvec![1; input_shape.rank()]
+        };
+        let axes: TVec<usize> = if let Some(i) = self.optional_axes_input {
+            let axes = params[i - 1]
+                .as_ref()
+                .context("StridedSlice is typable only if axis is a const")?
+                .cast_to::<i32>()?;
+            axes.as_slice::<i32>()?
+                .iter()
+                .map(|&i| if i < 0 { input_shape.rank() as i32 + i } else { i } as usize)
+                .collect()
+        } else {
+            (0..input_shape.rank()).collect()
+        };
+        let mut wire = inputs[0];
+        let begin = params[0].as_ref();
+        let end = params[1].as_ref();
+        for (ix, &axis) in axes.iter().enumerate() {
+            if let (Some(begin), Some(end)) = (begin, end) {
                 let d = &input_shape[axis];
-                let preped = self.prepare_one_dim(ix, &d, &params[0], &params[1], &strides)?;
-                if preped.stride > 0 {
-                    if preped.begin != 0.to_dim() || preped.end != input.shape[ix] {
-                        wire = target.wire_node(
-                            format!("{}.slice-axis-{}", prefix, axis),
-                            crate::ops::array::Slice::new(axis, preped.begin, preped.end),
-                            [wire].as_ref(),
-                        )?[0];
-                    }
+                let preped = self.prepare_one_dim(ix, &d, &begin, &end, &strides)?;
+                let (left, right) = if preped.stride > 0 {
+                    (preped.begin, preped.end)
                 } else {
-                    if preped.end != 0.to_dim() || preped.begin != input.shape[ix] {
-                        wire = target.wire_node(
-                            format!("{}.slice-axis-{}", prefix, axis),
-                            crate::ops::array::Slice::new(axis, preped.end + 1, preped.begin + 1),
-                            [wire].as_ref(),
-                        )?[0];
-                    }
-                }
+                    (preped.end + 1, preped.begin + 1)
+                };
+                wire = target.wire_node(
+                    format!("{}.slice-axis-{}", prefix, axis),
+                    crate::ops::array::Slice::new(axis, left, right),
+                    [wire].as_ref(),
+                )?[0];
                 if preped.stride != 1 {
                     wire = target.wire_node(
                         format!("{}.stride-axis-{}", prefix, axis),
@@ -279,27 +278,50 @@ impl Expansion for StridedSlice {
                         [wire].as_ref(),
                     )?[0];
                 }
-            }
-            let mut shrink = input
-                .shape
-                .iter()
-                .enumerate()
-                .filter(|(ix, _d)| self.must_shrink(*ix))
-                .map(|pair| pair.0)
-                .collect::<Vec<_>>();
-            shrink.sort();
-            for axis in shrink.iter().rev() {
+            } else if strides[ix] == 1 {
+                let left = target.wire_node(
+                    format!("{}.slice-axis-{}-start", prefix, axis),
+                    crate::ops::array::Slice::new(0, ix, ix + 1),
+                    &[inputs[1]],
+                )?;
+                let left = target.wire_node(
+                    format!("{}.slice-axis-{}-start-rm-axis", prefix, axis),
+                    AxisOp::Rm(0),
+                    &left,
+                )?[0];
+                let right = target.wire_node(
+                    format!("{}.slice-axis-{}-end", prefix, axis),
+                    crate::ops::array::Slice::new(0, ix, ix + 1),
+                    &[inputs[2]],
+                )?;
+                let right = target.wire_node(
+                    format!("{}.slice-axis-{}-end-rm-axis", prefix, axis),
+                    AxisOp::Rm(0),
+                    &right,
+                )?[0];
                 wire = target.wire_node(
-                    format!("{}.RmDim-{}", prefix, axis),
-                    AxisOp::Rm(*axis),
-                    [wire].as_ref(),
+                    format!("{}.slice-axis-{}", prefix, axis),
+                    tract_core::ops::array::DynSlice::new(axis, true, true),
+                    &[wire, left, right],
                 )?[0];
             }
-            target.rename_node(wire.node, prefix)?;
-            Ok(tvec!(wire))
-        } else {
-            bail!("StridedSlice in not typable when params are dynamic: got:{:?}", params);
         }
+        let mut shrink = input_shape
+            .iter()
+            .enumerate()
+            .filter(|(ix, _d)| self.must_shrink(*ix))
+            .map(|pair| pair.0)
+            .collect::<Vec<_>>();
+        shrink.sort();
+        for axis in shrink.iter().rev() {
+            wire = target.wire_node(
+                format!("{}.RmDim-{}", prefix, axis),
+                AxisOp::Rm(*axis),
+                [wire].as_ref(),
+            )?[0];
+        }
+        target.rename_node(wire.node, prefix)?;
+        Ok(tvec!(wire))
     }
 }
 
